@@ -20,6 +20,20 @@ test_that("output is a 'ggplot' object", {
   a <- data.frame(letters[1:3], 1:3)
   expect_match(class(pie_bake_pro(a, template = "eaten3")), "gg")
   expect_match(class(pie_bake_pro(a, template = "eaten1", title = "gg")), "gg")
+  expect_match(class(pie_bake_pro(a, template = "cirbar1", title = "prova")), "gg")
+  expect_match(class(pie_bake_pro(a, template = "cirbar2")), "gg")
+  expect_match(class(pie_bake_pro(a, template = "cirbar3", title = "ciao")), "gg")
+  expect_match(class(pie_bake_pro(a, template = "cirbar4", title = "nop")), "gg")
+  expect_match(class(pie_bake_pro(a, template = "cirbar5")), "gg")
+})
+
+test_that("output is NULL when the template is a spider chart", {
+  a <- data.frame(letters[1:3], 1:3)
+  expect_match(class(pie_bake_pro(a, template = "spider1")), "NULL")
+  expect_match(class(pie_bake_pro(a, template = "spider2")), "NULL")
+  expect_match(class(pie_bake_pro(a, template = "spider3")), "NULL")
+  expect_match(class(pie_bake_pro(a, template = "spider4")), "NULL")
+  expect_match(class(pie_bake_pro(a, template = "spider5")), "NULL")
 })
 
 test_that("title specification works", {
@@ -47,3 +61,5 @@ test_that("also tibbles can be baked", {
   expect_match(class(pie_bake_pro(b, template = "dart4")), "gg")
   expect_match(class(pie_bake_pro(c, template = "dart5")), "gg")
 })
+
+
